/*
 * Copyright (c) 2017 Atmark Techno, Inc. All Rights Reserved.
 *
 * Based on: imx6_spl.h
 *   Copyright (C) 2014 Gateworks Corporation
 *   Author: Tim Harvey <tharvey@gateworks.com>
 *
 * SPDX-License-Identifier:     GPL-2.0+
 */
#ifndef __IMX7_SPL_CONFIG_H
#define __IMX7_SPL_CONFIG_H

#ifdef CONFIG_SPL

#define CONFIG_SPL_FRAMEWORK
#define CONFIG_SPL_BOARD_INIT

/*
 * See Figure 6-21 in IMX7D Reference Manual Rev.1, 01/2018:
 *  - IMX7D OCRAM Free Area is from 0x00910000 to 0x00946C00.
 *  - The BOOT ROM loads 4KB header which contains the IVT, DCD and some
 *    paddings.
 *    It is attached on top of SPL U-Boot image.
 *
 *    Moreover, Mask 3N09P has errata "e11166" which makes top 4KB area be
 *    unavailable during boot time.
 *    See: https://www.nxp.com/docs/en/errata/IMX7DS_3N09P.pdf
 *
 *    Thus max size we can use is 0x00912000 - 0x00946C00 or 60KB.
 */
#define CONFIG_SYS_THUMB_BUILD
#define CONFIG_SPL_LDSCRIPT	"arch/arm/cpu/armv7/omap-common/u-boot-spl.lds"
#define CONFIG_SPL_TEXT_BASE		0x00912000
#define CONFIG_SPL_MAX_SIZE		0xE000		/* 60KB */
#define CONFIG_SPL_STACK		0x00946C00
#define CONFIG_SPL_BSS_START_ADDR	(CONFIG_SPL_TEXT_BASE + \
					CONFIG_SPL_MAX_SIZE)
#define CONFIG_SPL_BSS_MAX_SIZE		0x1000		/* 4KB */
#define CONFIG_SYS_SPL_MALLOC_START	(CONFIG_SPL_BSS_START_ADDR + \
					 CONFIG_SPL_BSS_MAX_SIZE)
#define CONFIG_SYS_SPL_MALLOC_SIZE	0x8000		/* 32KB */
#define CONFIG_SPL_PAD_TO		0x11000		/* CONFIG_SPL_MAX_SIZE +
							   CONFIG_SPL_BSS_MAX_SIZE */

#define CONFIG_SPL_LIBCOMMON_SUPPORT
#define CONFIG_SPL_LIBGENERIC_SUPPORT
#define CONFIG_SPL_SERIAL_SUPPORT
#define CONFIG_SPL_I2C_SUPPORT
#define CONFIG_SPL_GPIO_SUPPORT
#define CONFIG_SPL_WATCHDOG_SUPPORT

/* NAND support */
#if defined(CONFIG_SPL_NAND_SUPPORT)
#define CONFIG_SPL_NAND_MXS
#define CONFIG_SPL_DMA_SUPPORT
#endif /* CONFIG_SPL_NAND_SUPPORT */

/* MMC support */
#if defined(CONFIG_SPL_MMC_SUPPORT)
#define CONFIG_SYS_MMCSD_RAW_MODE_U_BOOT_SECTOR	((CONFIG_SPL_PAD_TO + 0x400) / 512)
#define CONFIG_SYS_U_BOOT_MAX_SIZE_SECTORS	800 /* 400 KB */
#define CONFIG_SYS_MMCSD_FS_BOOT_PARTITION	1
#define CONFIG_SYS_MONITOR_LEN			(CONFIG_SYS_U_BOOT_MAX_SIZE_SECTORS / 2 * 1024)
#define CONFIG_SPL_ABORT_ON_RAW_IMAGE
#endif /* CONFIG_SPL_MMC_SUPPORT */

#if defined(CONFIG_SPL_SPI_SUPPORT)
#define CONFIG_SPL_SPI_LOAD
#define CONFIG_SPL_SPI_FLASH_SUPPORT
#define CONFIG_SYS_SPI_U_BOOT_OFFS	(CONFIG_SPL_PAD_TO + 0x400)
#endif /* CONFIG_SPL_SPI_SUPPORT */

/* Define the payload for FAT/EXT support */
#if defined(CONFIG_SPL_FAT_SUPPORT) || defined(CONFIG_SPL_EXT_SUPPORT)
#define CONFIG_SPL_FS_LOAD_PAYLOAD_NAME  "u-boot.img"
#define CONFIG_SPL_LIBDISK_SUPPORT
#endif /* CONFIG_SPL_FAT_SUPPORT) || CONFIG_SPL_EXT_SUPPORT */

#endif /* CONFIG_SPL */

#endif /* __IMX7_SPL_CONFIG_H */
